@@ -92,7 +92,10 @@ class Reagent:
         self._intermediates = {}
 
     def __repr__(self):
-        attr_strs = ', '.join(f'{k}={v!r}' for k, v in self._attrs.items())
+        attrs = list(self._attrs.items())
+        if isinstance(self, IntermediateMixin):
+            attrs.insert(0, ('step', self.step))
+        attr_strs = ', '.join(f'{k}={v!r}' for k, v in attrs)
         return f'{self.__class__.__qualname__}({attr_strs})'
 
     def check(self):
@@ -180,6 +183,14 @@ class Reagent:
     def get_dependencies(self):
         return set(self.synthesis_maker.dependencies)
 
+    def get_pending(self):
+        pending = self._attrs.get('pending', False)
+
+        if callable(pending):
+            pending = pending()
+
+        return pending
+
     def get_maker_attr(self, attr, default=NO_DEFAULT):
         try:
             makers = [self.synthesis_maker, *self.cleanup_makers]
@@ -352,6 +363,25 @@ class Molecule(Reagent):
     def get_conc_mg_mL(self):
         return self.get_conc('mg/mL').value
 
+    def get_volume(self):
+        volume = self._attrs.get('volume')
+
+        if volume is None:
+            volume = self.get_maker_attr('product_volume', None)
+
+        if volume is None:
+            raise QueryError("no volume specified", culprit=self)
+
+        # Allow parsing to be deferred until the volume is accessed, so errors 
+        # don't prevent the rest of the database from loading.
+        if callable(volume):
+            volume = volume()
+
+        return volume
+
+    def get_volume_uL(self):
+        return self.volume.convert_unit('µL', VOLUME_CONVERSION_FACTORS).value
+
     def _check_seq(self):
         from Bio import pairwise2
         from Bio.pairwise2 import format_alignment
