@@ -9,7 +9,7 @@ from freezerbox.model import *
 from schema_helpers import *
 from mock_model import *
 
-kwargs_schema = lambda expected=eval: Schema({
+kwargs_schema = lambda expected=eval_freezerbox: Schema({
     Optional('kwargs', {}): empty_ok({str: eval_freezerbox}),
     **error_or(**{
         'expected': expected,
@@ -126,6 +126,16 @@ def test_reagent_repr(kwargs, expected, error):
     with error:
         assert repr(x1) == expected
 
+def test_reagent_intermediate_repr():
+    db = Database()
+    db['x1'] = x1 = MockReagent(
+            synthesis=Fields(['m'], {}),
+    )
+    i1 = x1.make_intermediate(0)
+
+    assert repr(x1) == "MockReagent(synthesis=Fields(['m'], {}))"
+    assert repr(i1) == "MockReagentIntermediate(step=0, synthesis=Fields(['m'], {}))"
+
 @parametrize_from_file(schema=kwargs_schema())
 def test_reagent_name(kwargs, expected, error):
     db = Database()
@@ -154,6 +164,13 @@ def test_reagent_desc(kwargs, expected, error):
     with error:
         assert x1.desc == expected
 
+@parametrize_from_file(schema=kwargs_schema())
+def test_reagent_pending(kwargs, expected, error):
+    db = Database()
+    db['x1'] = x1 = MockReagent(**kwargs)
+    with error:
+        assert x1.pending == expected
+
 def test_reagent_maker_args_1():
     db = Database()
     db['x1'] = x1 = MockReagent(
@@ -341,6 +358,18 @@ def test_molecule_conc(kwargs, expected, error, mock_plugins):
         with error:
             assert get_by_unit[q.unit]() == pytest.approx(q.value)
 
+@parametrize_from_file(
+        schema=kwargs_schema({str: eval_freezerbox}),
+)
+def test_molecule_volume(kwargs, expected, error, mock_plugins):
+    db = Database()
+    db['x1'] = x1 = MockMolecule(**kwargs)
+
+    with error:
+        assert x1.volume == expected['quantity']
+    with error:
+        assert x1.volume_uL == expected['uL']
+
 
 def test_protein_mw():
     db = Database()
